@@ -46,8 +46,6 @@ pub mod error_detail;
 pub use self::error_detail::ErrorDetail;
 pub mod event_source;
 pub use self::event_source::EventSource;
-pub mod event_type;
-pub use self::event_type::EventType;
 pub mod experiment;
 pub use self::experiment::Experiment;
 pub mod experiment_device_config;
@@ -276,6 +274,14 @@ pub mod telemetry_event_polymorphic_request;
 pub use self::telemetry_event_polymorphic_request::TelemetryEventPolymorphicRequest;
 pub mod telemetry_event_request;
 pub use self::telemetry_event_request::TelemetryEventRequest;
+pub mod test_event;
+pub use self::test_event::TestEvent;
+pub mod test_event_event_type_enum;
+pub use self::test_event_event_type_enum::TestEventEventTypeEnum;
+pub mod test_event_name;
+pub use self::test_event_name::TestEventName;
+pub mod test_event_request;
+pub use self::test_event_request::TestEventRequest;
 pub mod token_response;
 pub use self::token_response::TokenResponse;
 pub mod user;
@@ -284,6 +290,8 @@ pub mod user_request;
 pub use self::user_request::UserRequest;
 pub mod web_rtc_event;
 pub use self::web_rtc_event::WebRtcEvent;
+pub mod web_rtc_event_event_type_enum;
+pub use self::web_rtc_event_event_type_enum::WebRtcEventEventTypeEnum;
 pub mod web_rtc_event_name;
 pub use self::web_rtc_event_name::WebRtcEventName;
 pub mod web_rtc_event_request;
